# -*- coding: utf-8 -*-

# Form implementation generated from reading ui file 'iosshy/tunneldialog.ui'
#
# Created: Thu Jan 20 08:29:15 2011
#      by: PyQt4 UI code generator 4.8.2
#
# WARNING! All changes made in this file will be lost!

from PyQt4 import QtCore, QtGui

try:
    _fromUtf8 = QtCore.QString.fromUtf8
except AttributeError:
    _fromUtf8 = lambda s: s

class Ui_TunnelDialog(object):
    def setupUi(self, TunnelDialog):
        TunnelDialog.setObjectName(_fromUtf8("TunnelDialog"))
        TunnelDialog.resize(636, 381)
        icon = QtGui.QIcon()
        icon.addPixmap(QtGui.QPixmap(_fromUtf8(":/icons/network-server.png")), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        TunnelDialog.setWindowIcon(icon)
        self.gridLayout = QtGui.QGridLayout(TunnelDialog)
        self.gridLayout.setObjectName(_fromUtf8("gridLayout"))
        self.listTunnels = QtGui.QListWidget(TunnelDialog)
        sizePolicy = QtGui.QSizePolicy(QtGui.QSizePolicy.Fixed, QtGui.QSizePolicy.Expanding)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.listTunnels.sizePolicy().hasHeightForWidth())
        self.listTunnels.setSizePolicy(sizePolicy)
        self.listTunnels.setEditTriggers(QtGui.QAbstractItemView.NoEditTriggers)
        self.listTunnels.setProperty(_fromUtf8("showDropIndicator"), False)
        self.listTunnels.setSelectionBehavior(QtGui.QAbstractItemView.SelectRows)
        self.listTunnels.setObjectName(_fromUtf8("listTunnels"))
        self.gridLayout.addWidget(self.listTunnels, 0, 0, 1, 1)
        self.verticalLayout = QtGui.QVBoxLayout()
        self.verticalLayout.setObjectName(_fromUtf8("verticalLayout"))
        self.grpTunnelProperties = QtGui.QGroupBox(TunnelDialog)
        self.grpTunnelProperties.setEnabled(False)
        self.grpTunnelProperties.setObjectName(_fromUtf8("grpTunnelProperties"))
        self.formLayout = QtGui.QFormLayout(self.grpTunnelProperties)
        self.formLayout.setFieldGrowthPolicy(QtGui.QFormLayout.ExpandingFieldsGrow)
        self.formLayout.setObjectName(_fromUtf8("formLayout"))
        self.lblName = QtGui.QLabel(self.grpTunnelProperties)
        self.lblName.setObjectName(_fromUtf8("lblName"))
        self.formLayout.setWidget(0, QtGui.QFormLayout.LabelRole, self.lblName)
        self.txtName = QtGui.QLineEdit(self.grpTunnelProperties)
        self.txtName.setObjectName(_fromUtf8("txtName"))
        self.formLayout.setWidget(0, QtGui.QFormLayout.FieldRole, self.txtName)
        self.lblPort = QtGui.QLabel(self.grpTunnelProperties)
        self.lblPort.setObjectName(_fromUtf8("lblPort"))
        self.formLayout.setWidget(1, QtGui.QFormLayout.LabelRole, self.lblPort)
        self.txtPort = QtGui.QLineEdit(self.grpTunnelProperties)
        self.txtPort.setObjectName(_fromUtf8("txtPort"))
        self.formLayout.setWidget(1, QtGui.QFormLayout.FieldRole, self.txtPort)
        self.lblLocalPort = QtGui.QLabel(self.grpTunnelProperties)
        self.lblLocalPort.setObjectName(_fromUtf8("lblLocalPort"))
        self.formLayout.setWidget(2, QtGui.QFormLayout.LabelRole, self.lblLocalPort)
        self.txtLocalPort = QtGui.QLineEdit(self.grpTunnelProperties)
        self.txtLocalPort.setObjectName(_fromUtf8("txtLocalPort"))
        self.formLayout.setWidget(2, QtGui.QFormLayout.FieldRole, self.txtLocalPort)
        self.lblCommand = QtGui.QLabel(self.grpTunnelProperties)
        self.lblCommand.setObjectName(_fromUtf8("lblCommand"))
        self.formLayout.setWidget(3, QtGui.QFormLayout.LabelRole, self.lblCommand)
        self.txtCommand = QtGui.QLineEdit(self.grpTunnelProperties)
        self.txtCommand.setObjectName(_fromUtf8("txtCommand"))
        self.formLayout.setWidget(3, QtGui.QFormLayout.FieldRole, self.txtCommand)
        self.chkCloseOnTerm = QtGui.QCheckBox(self.grpTunnelProperties)
        self.chkCloseOnTerm.setObjectName(_fromUtf8("chkCloseOnTerm"))
        self.formLayout.setWidget(4, QtGui.QFormLayout.FieldRole, self.chkCloseOnTerm)
        self.verticalLayout.addWidget(self.grpTunnelProperties)
        self.grpSshProperties = QtGui.QGroupBox(TunnelDialog)
        self.grpSshProperties.setEnabled(False)
        self.grpSshProperties.setObjectName(_fromUtf8("grpSshProperties"))
        self.formLayout_2 = QtGui.QFormLayout(self.grpSshProperties)
        self.formLayout_2.setFieldGrowthPolicy(QtGui.QFormLayout.ExpandingFieldsGrow)
        self.formLayout_2.setObjectName(_fromUtf8("formLayout_2"))
        self.lblHost = QtGui.QLabel(self.grpSshProperties)
        self.lblHost.setObjectName(_fromUtf8("lblHost"))
        self.formLayout_2.setWidget(0, QtGui.QFormLayout.LabelRole, self.lblHost)
        self.txtHost = QtGui.QLineEdit(self.grpSshProperties)
        self.txtHost.setObjectName(_fromUtf8("txtHost"))
        self.formLayout_2.setWidget(0, QtGui.QFormLayout.FieldRole, self.txtHost)
        self.lblSshPort = QtGui.QLabel(self.grpSshProperties)
        self.lblSshPort.setObjectName(_fromUtf8("lblSshPort"))
        self.formLayout_2.setWidget(1, QtGui.QFormLayout.LabelRole, self.lblSshPort)
        self.txtSshPort = QtGui.QLineEdit(self.grpSshProperties)
        self.txtSshPort.setObjectName(_fromUtf8("txtSshPort"))
        self.formLayout_2.setWidget(1, QtGui.QFormLayout.FieldRole, self.txtSshPort)
        self.lblUsername = QtGui.QLabel(self.grpSshProperties)
        self.lblUsername.setObjectName(_fromUtf8("lblUsername"))
        self.formLayout_2.setWidget(2, QtGui.QFormLayout.LabelRole, self.lblUsername)
        self.txtUsername = QtGui.QLineEdit(self.grpSshProperties)
        self.txtUsername.setObjectName(_fromUtf8("txtUsername"))
        self.formLayout_2.setWidget(2, QtGui.QFormLayout.FieldRole, self.txtUsername)
        self.verticalLayout.addWidget(self.grpSshProperties)
        self.gridLayout.addLayout(self.verticalLayout, 0, 1, 1, 1)
        self.horizontalLayout = QtGui.QHBoxLayout()
        self.horizontalLayout.setObjectName(_fromUtf8("horizontalLayout"))
        self.btnAddTunnel = QtGui.QPushButton(TunnelDialog)
        sizePolicy = QtGui.QSizePolicy(QtGui.QSizePolicy.Ignored, QtGui.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.btnAddTunnel.sizePolicy().hasHeightForWidth())
        self.btnAddTunnel.setSizePolicy(sizePolicy)
        icon1 = QtGui.QIcon()
        icon1.addPixmap(QtGui.QPixmap(_fromUtf8(":/icons/list-add.png")), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.btnAddTunnel.setIcon(icon1)
        self.btnAddTunnel.setObjectName(_fromUtf8("btnAddTunnel"))
        self.horizontalLayout.addWidget(self.btnAddTunnel)
        self.btnDuplicateTunnel = QtGui.QPushButton(TunnelDialog)
        sizePolicy = QtGui.QSizePolicy(QtGui.QSizePolicy.Ignored, QtGui.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.btnDuplicateTunnel.sizePolicy().hasHeightForWidth())
        self.btnDuplicateTunnel.setSizePolicy(sizePolicy)
        icon2 = QtGui.QIcon()
        icon2.addPixmap(QtGui.QPixmap(_fromUtf8(":/icons/edit-copy.png")), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.btnDuplicateTunnel.setIcon(icon2)
        self.btnDuplicateTunnel.setObjectName(_fromUtf8("btnDuplicateTunnel"))
        self.horizontalLayout.addWidget(self.btnDuplicateTunnel)
        self.btnRemoveTunnel = QtGui.QPushButton(TunnelDialog)
        sizePolicy = QtGui.QSizePolicy(QtGui.QSizePolicy.Ignored, QtGui.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.btnRemoveTunnel.sizePolicy().hasHeightForWidth())
        self.btnRemoveTunnel.setSizePolicy(sizePolicy)
        icon3 = QtGui.QIcon()
        icon3.addPixmap(QtGui.QPixmap(_fromUtf8(":/icons/list-remove.png")), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.btnRemoveTunnel.setIcon(icon3)
        self.btnRemoveTunnel.setObjectName(_fromUtf8("btnRemoveTunnel"))
        self.horizontalLayout.addWidget(self.btnRemoveTunnel)
        self.gridLayout.addLayout(self.horizontalLayout, 1, 0, 1, 1)
        self.horizontalLayout_2 = QtGui.QHBoxLayout()
        self.horizontalLayout_2.setObjectName(_fromUtf8("horizontalLayout_2"))
        spacerItem = QtGui.QSpacerItem(40, 20, QtGui.QSizePolicy.Expanding, QtGui.QSizePolicy.Minimum)
        self.horizontalLayout_2.addItem(spacerItem)
        self.btnOK = QtGui.QPushButton(TunnelDialog)
        icon4 = QtGui.QIcon()
        icon4.addPixmap(QtGui.QPixmap(_fromUtf8(":/icons/dialog-ok.png")), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.btnOK.setIcon(icon4)
        self.btnOK.setDefault(True)
        self.btnOK.setObjectName(_fromUtf8("btnOK"))
        self.horizontalLayout_2.addWidget(self.btnOK)
        self.gridLayout.addLayout(self.horizontalLayout_2, 1, 1, 1, 1)
        self.lblName.setBuddy(self.txtName)
        self.lblPort.setBuddy(self.txtPort)
        self.lblLocalPort.setBuddy(self.txtLocalPort)
        self.lblCommand.setBuddy(self.txtCommand)
        self.lblHost.setBuddy(self.txtHost)
        self.lblSshPort.setBuddy(self.txtHost)
        self.lblUsername.setBuddy(self.txtUsername)

        self.retranslateUi(TunnelDialog)
        QtCore.QObject.connect(self.btnOK, QtCore.SIGNAL(_fromUtf8("clicked()")), TunnelDialog.hide)
        QtCore.QMetaObject.connectSlotsByName(TunnelDialog)
        TunnelDialog.setTabOrder(self.listTunnels, self.btnAddTunnel)
        TunnelDialog.setTabOrder(self.btnAddTunnel, self.btnDuplicateTunnel)
        TunnelDialog.setTabOrder(self.btnDuplicateTunnel, self.btnRemoveTunnel)
        TunnelDialog.setTabOrder(self.btnRemoveTunnel, self.txtName)
        TunnelDialog.setTabOrder(self.txtName, self.txtPort)
        TunnelDialog.setTabOrder(self.txtPort, self.txtLocalPort)
        TunnelDialog.setTabOrder(self.txtLocalPort, self.txtCommand)
        TunnelDialog.setTabOrder(self.txtCommand, self.chkCloseOnTerm)
        TunnelDialog.setTabOrder(self.chkCloseOnTerm, self.txtHost)
        TunnelDialog.setTabOrder(self.txtHost, self.txtSshPort)
        TunnelDialog.setTabOrder(self.txtSshPort, self.txtUsername)
        TunnelDialog.setTabOrder(self.txtUsername, self.btnOK)

    def retranslateUi(self, TunnelDialog):
        TunnelDialog.setWindowTitle(QtGui.QApplication.translate("TunnelDialog", "IOSSHy - Tunnel Configuration", None, QtGui.QApplication.UnicodeUTF8))
        self.grpTunnelProperties.setTitle(QtGui.QApplication.translate("TunnelDialog", "Tunnel Properties", None, QtGui.QApplication.UnicodeUTF8))
        self.lblName.setText(QtGui.QApplication.translate("TunnelDialog", "Name", None, QtGui.QApplication.UnicodeUTF8))
        self.lblPort.setText(QtGui.QApplication.translate("TunnelDialog", "Remote Port", None, QtGui.QApplication.UnicodeUTF8))
        self.txtPort.setInputMask(QtGui.QApplication.translate("TunnelDialog", "00009; ", None, QtGui.QApplication.UnicodeUTF8))
        self.lblLocalPort.setText(QtGui.QApplication.translate("TunnelDialog", "Local Port", None, QtGui.QApplication.UnicodeUTF8))
        self.txtLocalPort.setToolTip(QtGui.QApplication.translate("TunnelDialog", "If local port is set to 0, a random high-numbered port will be selected", None, QtGui.QApplication.UnicodeUTF8))
        self.txtLocalPort.setInputMask(QtGui.QApplication.translate("TunnelDialog", "00009; ", None, QtGui.QApplication.UnicodeUTF8))
        self.lblCommand.setText(QtGui.QApplication.translate("TunnelDialog", "Command", None, QtGui.QApplication.UnicodeUTF8))
        self.txtCommand.setToolTip(QtGui.QApplication.translate("TunnelDialog", "The string {port} in the command line will be replaced by the local port number (useful when the local port is selected by IOSSHy)", None, QtGui.QApplication.UnicodeUTF8))
        self.chkCloseOnTerm.setText(QtGui.QApplication.translate("TunnelDialog", "Automatically close on command termination", None, QtGui.QApplication.UnicodeUTF8))
        self.grpSshProperties.setTitle(QtGui.QApplication.translate("TunnelDialog", "SSH connection options", None, QtGui.QApplication.UnicodeUTF8))
        self.lblHost.setText(QtGui.QApplication.translate("TunnelDialog", "Host", None, QtGui.QApplication.UnicodeUTF8))
        self.lblSshPort.setText(QtGui.QApplication.translate("TunnelDialog", "Port", None, QtGui.QApplication.UnicodeUTF8))
        self.txtSshPort.setInputMask(QtGui.QApplication.translate("TunnelDialog", "00009; ", None, QtGui.QApplication.UnicodeUTF8))
        self.lblUsername.setText(QtGui.QApplication.translate("TunnelDialog", "Username", None, QtGui.QApplication.UnicodeUTF8))
        self.btnAddTunnel.setText(QtGui.QApplication.translate("TunnelDialog", "&Add", None, QtGui.QApplication.UnicodeUTF8))
        self.btnDuplicateTunnel.setText(QtGui.QApplication.translate("TunnelDialog", "&Duplicate", None, QtGui.QApplication.UnicodeUTF8))
        self.btnRemoveTunnel.setText(QtGui.QApplication.translate("TunnelDialog", "&Remove", None, QtGui.QApplication.UnicodeUTF8))
        self.btnOK.setText(QtGui.QApplication.translate("TunnelDialog", "&OK", None, QtGui.QApplication.UnicodeUTF8))

import icons_rc
